pub enum Action {
Show 15 variants
ChangeView(u32),
CloseCurrentView,
CloseView(u32),
CreateView(PageType),
GoBackward,
GoForward,
GoToUrl(Url),
Refresh,
SendKeyboardEvent(Event),
SendMouseEvent(Event, Point),
Update,
Resize(Size<u32>),
CopySelection,
FetchComplete(ViewId, String, Result<(String, HashMap<String, String>), String>),
ImageFetchComplete(ViewId, String, Result<Vec<u8>, String>, bool, u64),
}Expand description
Handles Actions for Basic webview
Variants
ChangeView(u32)
Changes view to the desired view index
CloseCurrentView
Closes current window & makes last used view the current one
CloseView(u32)
Closes specific view index
CreateView(PageType)
Creates a new view and makes its index view + 1
GoBackward
GoForward
GoToUrl(Url)
Refresh
SendKeyboardEvent(Event)
SendMouseEvent(Event, Point)
Update
Allows users to control when the browser engine proccesses interactions in subscriptions
Resize(Size<u32>)
CopySelection
Copy the current text selection to clipboard
FetchComplete(ViewId, String, Result<(String, HashMap<String, String>), String>)
Internal: carries the result of a URL fetch for engines without native URL support.
On success returns (html, css_cache).
ImageFetchComplete(ViewId, String, Result<Vec<u8>, String>, bool, u64)
Internal: carries the result of an image fetch.
The bool is redraw_on_ready — when true, the image doesn’t affect
layout so doc.render() can be skipped (redraw only).
The u64 is the navigation epoch — stale results are discarded.